@@ -31,7 +31,7 @@ class MyMangaListOrg(Provider, Std):
         return []
 
     def prepare_cookies(self):
-        self.cf_protect(self.get_url())
+        self.cf_scrape(self.get_url())
 
     def get_cover(self) -> str:
         return self._cover_from_content('img.manga_info_image')
